.. pyIEM documentation master file, created by
   sphinx-quickstart on Thu Jan 22 11:11:10 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyIEM's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 3

   api/modules.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

